@@ -2,17 +2,17 @@
 #'
 #' A matrix containing simulated mRNA expression levels for 358 subjects (rows)
 #' and 500 features (columns).
-"geneExpr"
+"X1"
 
 #' A synthetic miRNA expression dataset.
 #'
 #' A matrix containing simulated miRNA expression levels for 358 subjects (rows)
 #' and 100 features (columns).
-"mirnaExpr"
+"X2"
 
 #' A synthetic phenotype dataset.
 #'
 #' A matrix containing simulated quantitative phenotype measures for 358 
 #' subjects (rows).
-"pheno"
+"Y"
 
