@@ -10,12 +10,7 @@
 #
 ################################################################################
 
-######## Package that we need ########
-# You only need to install once #
-# install.packages("PMA", repos="http://cran.r-project.org")
 
-requireNamespace("PMA", quietly = TRUE)
-# library(PMA)
 
 
 
@@ -62,19 +57,14 @@ myMultiCCA <- function(xlist, penalty=NULL, ws=NULL, niter=25,
   #   If CCcoef = NULL (default), then the objective function is the total sum
   #   of all pairwise CC. It can also be a coefficient vector that follows the
   #   column order of combn(K, 2).
-
+  
   if(ncol(xlist[[length(xlist)]]) > 1){
-    out <- PMA::MultiCCA(xlist, penalty=penalty, ws=ws, niter=niter,
-                    type=type, ncomponents=ncomponents, trace=FALSE,
-                    standardize=standardize)
-
-  }else{
     # The Kth data set in xlist is a one dimensional phenotype
     call <- match.call()
     K <- length(xlist)
     pair_CC <- utils::combn(K, 2)
     num_CC <- ncol(utils::combn(K, 2))
-
+    
     # Check canonical correlation coefficients.
     if(is.null(CCcoef)){CCcoef <- rep(1, num_CC)}
     if(length(CCcoef) != num_CC){
@@ -82,7 +72,7 @@ myMultiCCA <- function(xlist, penalty=NULL, ws=NULL, niter=25,
                   Please provide ", num_CC, " numerical values for CCcoef.
                   Be sure to match combn(K,2) column order."))
     }
-
+    
     # Check data type.
     if(length(type)==1){# Expand a single type to a vector of length(xlist).
       if(type != "standard"){
@@ -93,10 +83,113 @@ myMultiCCA <- function(xlist, penalty=NULL, ws=NULL, niter=25,
       stop("Type must be a vector of length 1, or length(xlist)")}
     if(sum(type!="standard")>0){
       stop("Each element of type must be standard and not ordered.")}
-
+    
     # Standardize or not.
     if(standardize){xlist <- lapply(xlist, scale)}
-
+    
+    # Initialize weights.
+    if(!is.null(ws)){
+      makenull <- FALSE
+      for(i in seq_len(K)){
+        if(ncol(ws[[i]])<ncomponents) makenull <- TRUE
+      }
+      if(makenull) ws <- NULL
+    }
+    if(is.null(ws)){
+      ws <- list()
+      for(i in seq_len(K)){
+        ws[[i]] <- matrix(svd(xlist[[i]])$v[,seq_len(ncomponents)], ncol=ncomponents)
+      }
+      # ws[[K]] <- 1
+    }
+    ws.init <- ws
+    
+    # Check penalties.
+    if(is.null(penalty)){
+      penalty <- rep(NA, K)
+      penalty[type=="standard"] <- 4 # this is the default value of sumabs
+      for(k in seq_len(K)){
+        if(type[k]=="ordered"){
+          stop("Current version requires all element types to be standard (not ordered).")
+        }
+      }
+    }
+    if(length(penalty)==1) penalty <- rep(penalty, K)
+    if(sum(penalty<1 & type=="standard")){
+      stop("Cannot constrain sum of absolute values of weights to be less than
+           1.")
+    }
+    for(i in seq_len(K)){
+      if(type[i]=="standard" && penalty[i]>sqrt(ncol(xlist[[i]]))){
+        stop("L1 bound of weights should be no more than sqrt of the number of
+             columns of the corresponding data set.", fill=TRUE)
+      }
+    }
+    
+    ws.final <- ws.init
+    for(i in seq_len(K)){
+      ws.final[[i]] <- matrix(0, nrow=ncol(xlist[[i]]), ncol=ncomponents)
+    }
+    cors <- NULL
+    for(comp in seq_len(ncomponents)){
+      ws <- list()
+      for(i in seq_len(K)) ws[[i]] <- ws.init[[i]][,comp]
+      # ws[[K]] <- 1
+      curiter <- 1
+      crit.old <- -10
+      crit <- -20
+      storecrits <- NULL
+      
+      while(curiter<=niter && abs(crit.old-crit)/abs(crit.old)>.001 &&
+            crit.old!=0){
+        crit.old <- crit
+        crit <- myGetCrit(xlist, ws, pair_CC, CCcoef)
+        storecrits <- c(storecrits,crit)
+        if(trace) cat(curiter, fill=FALSE)
+        curiter <- curiter+1
+        for(i in seq_len(K)){
+          ws[[i]] <- myUpdateW(xlist, i, K, penalty[i], ws, type[i], ws.final,
+                               pair_CC, CCcoef)
+        }
+      }
+      
+      for(i in seq_len(K)) ws.final[[i]][,comp] <- ws[[i]]
+      cors <- c(cors, myGetCors(xlist, ws, pair_CC, CCcoef))
+    }
+    
+    out <- list(ws=ws.final, ws.init=ws.init, K=K, call=call, type=type,
+                penalty=penalty, cors=cors)
+    class(out) <- "MultiCCA"
+    
+  }else{
+    # The Kth data set in xlist is a one dimensional phenotype
+    call <- match.call()
+    K <- length(xlist)
+    pair_CC <- utils::combn(K, 2)
+    num_CC <- ncol(utils::combn(K, 2))
+    
+    # Check canonical correlation coefficients.
+    if(is.null(CCcoef)){CCcoef <- rep(1, num_CC)}
+    if(length(CCcoef) != num_CC){
+      stop(paste0("Invalid coefficients for pairwise canonical correlations.
+                  Please provide ", num_CC, " numerical values for CCcoef.
+                  Be sure to match combn(K,2) column order."))
+    }
+    
+    # Check data type.
+    if(length(type)==1){# Expand a single type to a vector of length(xlist).
+      if(type != "standard"){
+        stop("The phenotype data must be continuous and follow the type 'standard'. ")
+      }
+      type <- rep(type, K)}
+    if(length(type)!=K){
+      stop("Type must be a vector of length 1, or length(xlist)")}
+    if(sum(type!="standard")>0){
+      stop("Each element of type must be standard and not ordered.")}
+    
+    # Standardize or not.
+    if(standardize){xlist <- lapply(xlist, scale)}
+    
     # Initialize weights.
     if(!is.null(ws)){
       makenull <- FALSE
@@ -113,7 +206,7 @@ myMultiCCA <- function(xlist, penalty=NULL, ws=NULL, niter=25,
       ws[[K]] <- 1
     }
     ws.init <- ws
-
+    
     # Check penalties.
     if(is.null(penalty)){
       penalty <- rep(NA, K)
@@ -135,7 +228,7 @@ myMultiCCA <- function(xlist, penalty=NULL, ws=NULL, niter=25,
              columns of the corresponding data set.", fill=TRUE)
       }
     }
-
+    
     ws.final <- ws.init
     for(i in seq_len(K-1)){
       ws.final[[i]] <- matrix(0, nrow=ncol(xlist[[i]]), ncol=ncomponents)
@@ -149,7 +242,7 @@ myMultiCCA <- function(xlist, penalty=NULL, ws=NULL, niter=25,
       crit.old <- -10
       crit <- -20
       storecrits <- NULL
-
+      
       while(curiter<=niter && abs(crit.old-crit)/abs(crit.old)>.001 &&
             crit.old!=0){
         crit.old <- crit
@@ -159,14 +252,14 @@ myMultiCCA <- function(xlist, penalty=NULL, ws=NULL, niter=25,
         curiter <- curiter+1
         for(i in seq_len(K-1)){
           ws[[i]] <- myUpdateW(xlist, i, K, penalty[i], ws, type[i], ws.final,
-                             pair_CC, CCcoef)
+                               pair_CC, CCcoef)
         }
       }
-
+      
       for(i in seq_len(K-1)) ws.final[[i]][,comp] <- ws[[i]]
       cors <- c(cors, myGetCors(xlist, ws, pair_CC, CCcoef))
     }
-
+    
     out <- list(ws=ws.final, ws.init=ws.init, K=K, call=call, type=type,
                 penalty=penalty, cors=cors)
     class(out) <- "MultiCCA"
@@ -184,7 +277,7 @@ myMultiCCA <- function(xlist, penalty=NULL, ws=NULL, niter=25,
 
 # (INTERNAL)
 myUpdateW <- function(xlist, i, K, sumabsthis, ws, type="standard", ws.final,
-                    pair_CC, CCcoef){
+                      pair_CC, CCcoef){
   # Update canonical weights for the ith data set.
   #
   # xlist: Data list.
@@ -197,19 +290,19 @@ myUpdateW <- function(xlist, i, K, sumabsthis, ws, type="standard", ws.final,
   # pair_CC: The output of combn(K, 2). A two-row table that include indices for
   #   pairwise canonical correlaltions between members of xlist.
   # CCcoef: Optional coefficients for the pairwise canonical correlations (CC).
-
-
+  
+  
   tots0 <- vapply(seq_len(length(CCcoef)), function(x){
     pairx <- pair_CC[ , x]
     Xi <- xlist[[i]]
-
+    
     if(pairx[1] != i & pairx[[2]] != i){
       y <- rep(0, ncol(Xi))
     }else{
       if(pairx[1] == i){j <- pairx[2]}
       if(pairx[2] == i){j <- pairx[1]}
       Xj <- xlist[[j]]
-
+      
       # diagmat is the diagonal correlation matrix calculated using previous
       #   canonical directions.
       # If phenotype is included, only the first canonical direction is used.
@@ -220,16 +313,16 @@ myUpdateW <- function(xlist, i, K, sumabsthis, ws, type="standard", ws.final,
         ws.final[[i]]%*%(diagmat%*%(t(ws.final[[j]])%*%ws[[j]]))
       y <- y * CCcoef[x]
     }
-
+    
     return(y)
   }, numeric(ncol(xlist[[i]])))
   tots <- rowSums(tots0)
-
+  
   if(type=="standard"){
     sumabsthis <- BinarySearch(tots, sumabsthis)
     w <- soft(tots, sumabsthis)/l2n(soft(tots, sumabsthis))
   } else {
-      stop("Current version requires all element types to be standard (not ordered).")
+    stop("Current version requires all element types to be standard (not ordered).")
   }
   return(w)
 }
@@ -240,9 +333,9 @@ myGetCrit <- function(xlist, ws, pair_CC, CCcoef){
   # Compute the matrix form SmCCA objective function value for given weights.
   #
   # ws: First ncomponents columns of the v matrix of the SVD of $X_k$'s.
-
-
-
+  
+  
+  
   crits <- apply(pair_CC, 2, function(x){
     i <- x[1]
     j <- x[2]
@@ -262,7 +355,7 @@ myGetCors <- function(xlist, ws, pair_CC, CCcoef){
   # pair_CC: The output of combn(K, 2). A two-row table that include indices for
   #   pairwise canonical correlaltions between members of xlist.
   # CCcoef: Optional coefficients for the pairwise canonical correlations (CC).
-
+  
   CCs <- apply(pair_CC, 2, function(x){
     i <- x[1]
     j <- x[2]
@@ -270,7 +363,7 @@ myGetCors <- function(xlist, ws, pair_CC, CCcoef){
     if(is.na(y)){y <- 0}
     return(y)
   })
-
+  
   Cors <- sum(CCs * CCcoef)
   return(Cors)
 }
@@ -279,7 +372,7 @@ myGetCors <- function(xlist, ws, pair_CC, CCcoef){
 # (INTERNAL)
 BinarySearch <- function(argu,sumabs){
   #  Update sumabs so that the L1 norm of argu equals given penalty.
-
+  
   if(l2n(argu)==0 || sum(abs(argu/l2n(argu)))<=sumabs) return(0)
   lam1 <- 0
   lam2 <- max(abs(argu))-1e-5
@@ -302,7 +395,7 @@ BinarySearch <- function(argu,sumabs){
 # (INTERNAL)
 l2n <- function(vec){
   # Computes the L2 norm. If the norm is zero, set it to 0.05.
-
+  
   a <- sqrt(sum(vec^2))
   if(a==0) a <- .05
   return(a)
@@ -311,7 +404,7 @@ l2n <- function(vec){
 # (INTERNAL)
 soft <- function(x,d){
   # Soft thresholding.
-
+  
   return(sign(x)*pmax(0, abs(x)-d))
 }
 
@@ -324,4 +417,3 @@ soft <- function(x,d){
 
 
 
-
